@@ -1,12 +1,13 @@
 #!/usr/bin/env python3
 
 import sys, os, re, inspect, autoprop
-from pathlib import Path
-from textwrap import dedent
-from more_itertools import one, first
+
 from .layers import DictLayer, dict_like
 from ..utils import lookup, first_specified
 from ..errors import ConfigError
+from pathlib import Path
+from textwrap import dedent
+from more_itertools import one, first
 
 class Config:
     autoload = True
@@ -17,6 +18,10 @@ class Config:
     def __repr__(self):
         return f"{self.__class__.__name__}()"
 
+    @classmethod
+    def setup(cls, *args, **kwargs):
+        return lambda obj: cls(obj, *args, **kwargs)
+
     def load(self):
         raise NotImplmentedError
 
@@ -35,6 +40,14 @@ class ArgparseConfig(Config):
     parser_getter = lambda obj: obj.get_argparse()
     schema = None
 
+    def __init__(self, obj, **kwargs):
+        super().__init__(obj)
+
+        self.parser_getter = kwargs.get(
+                'parser_getter', unbind_method(self.parser_getter))
+        self.schema = kwargs.get(
+                'schema', self.schema)
+
     def load(self):
         args = self.parser.parse_args()
         yield DictLayer(
@@ -44,8 +57,8 @@ class ArgparseConfig(Config):
         )
 
     def get_parser(self):
-        # Might make sense to try caching the parser in the given object.
-        return self.__class__.parser_getter(self.obj)
+        # Might make sense to cache the parser.
+        return self.parser_getter(self.obj)
 
     def get_usage(self):
         return self.parser.format_help()
@@ -65,6 +78,24 @@ class DocoptConfig(Config):
     options_first = False
     schema = None
 
+    def __init__(self, obj, **kwargs):
+        super().__init__(obj)
+
+        self.usage_getter = kwargs.get(
+                'usage_getter', unbind_method(self.usage_getter))
+        self.version_getter = kwargs.get(
+                'version_getter', unbind_method(self.version_getter))
+        self.usage_io_getter = kwargs.get(
+                'usage_io_getter', unbind_method(self.usage_io_getter))
+        self.include_help = kwargs.get(
+                'include_help', self.include_help)
+        self.include_version = kwargs.get(
+                'include_version', self.include_version)
+        self.options_first = kwargs.get(
+                'options_first', self.options_first)
+        self.schema = kwargs.get(
+                'schema', unbind_method(self.schema))
+
     def load(self):
         import sys, docopt, contextlib
 
@@ -92,7 +123,7 @@ class DocoptConfig(Config):
     def get_usage(self):
         from mako.template import Template
 
-        usage = self.__class__.usage_getter(self.obj)
+        usage = self.usage_getter(self.obj)
         usage = dedent(usage)
         usage = Template(usage, strict_undefined=True).render(app=self.obj)
 
@@ -102,7 +133,7 @@ class DocoptConfig(Config):
         return usage
 
     def get_usage_io(self):
-        return self.__class__.usage_io_getter(self.obj)
+        return self.usage_io_getter(self.obj)
 
     def get_brief(self):
         import re
@@ -114,7 +145,7 @@ class DocoptConfig(Config):
         return first(sections, '').replace('\n', ' ').strip()
 
     def get_version(self):
-        return self.include_version and self.__class__.version_getter(self.obj)
+        return self.include_version and self.version_getter(self.obj)
 
 
 @autoprop
@@ -201,7 +232,7 @@ class FileConfig(Config):
     root_key = None
 
     def get_path(self):
-        return Path(self.__class__.path_getter(self.obj))
+        return Path(unbind_method(self.path_getter)(self.obj))
 
     def load(self):
         yield from self.load_from_path(
@@ -243,6 +274,9 @@ class TomlConfig(FileConfig):
 
     @staticmethod
     def _do_load(path):
+        # rtoml requires this.
+        path = Path(path)
+
         try:
             # Prefer rtoml, since it's much less buggy.  It's also much harder 
             # to install, though.
@@ -269,4 +303,5 @@ class NtConfig(FileConfig):
         import nestedtext as nt
         return nt.load(path)
 
-
+def unbind_method(f):
+    return getattr(f, '__func__', f)
