@@ -1,12 +1,24 @@
 #!/usr/bin/env python3
 
-from appcli import param, DefaultConfig
+from appcli import param, Config, DictLayer
+
+class DictConfig(Config):
+
+    def load(self):
+        yield DictLayer(values=self.values)
+
+class DictConfigAB(DictConfig):
+    values = {'a': 1, 'b': 1}
+
+class DictConfigAC(DictConfig):
+    values = {'a': 2, 'c': 2}
+
 
 def test_easy_1():
 
     class Foo:
         __config__ = [
-                DefaultConfig(a=1),
+                DictConfigAB,
         ]
 
         a = param()
@@ -17,8 +29,8 @@ def test_easy_1():
 def test_easy_2():
     class Foo:
         __config__ = [
-                DefaultConfig(a=1, b=1,    ),
-                DefaultConfig(a=2,      c=2),
+                DictConfigAB,
+                DictConfigAC,
         ]
 
         a = param()
